@@ -71,7 +71,6 @@
 #include <videodev_mjpeg.h>
 #include <pthread.h>
 
-#include "mjpeg_types.h"
 #include "mjpeg_logging.h"
 #include "liblavrec.h"
 #include "lav_io.h"
@@ -89,19 +88,6 @@
 
 #define NUM_AUDIO_TRIES 500 /* makes 10 seconds with 20 ms pause beetween tries */
 
-#define MAX_MBYTES_PER_FILE_64 ((0x3fffff) * 93/100)        /* 4Tb.  (Most filesystems have  */
-                                                            /* fundamental limitations around ~Tb) */
-#define MAX_MBYTES_PER_FILE_32 ((0x7fffffff >> 20) * 85/100)/* Is less than 2^31 and 2*10^9 */
-#if _FILE_OFFSET_BITS == 64
-#define MAX_MBYTES_PER_FILE MAX_MBYTES_PER_FILE_64
-#else
-#define MAX_MBYTES_PER_FILE MAX_MBYTES_PER_FILE_32
-                                  /* Maximum number of Mbytes per file.
-                                     We make a conservative guess since we
-                                     only count the number of bytes output
-                                     and don't know how big the control
-                                     information will be */
-#endif
 #define MIN_MBYTES_FREE 10        /* Minimum number of Mbytes that should
                                      stay free on the file system, this is also
                                      only a guess */
@@ -111,7 +97,6 @@
 
 #define VALUE_NOT_FILLED -10000
 
-
 typedef struct {
    int    interlaced;                         /* is the video interlaced (even/odd-first)? */
    int    width;                              /* width of the captured frames */
@@ -419,14 +404,14 @@ static int lavrec_autodetect_signal(lavrec_t *info)
 
    lavrec_msg(LAVREC_MSG_INFO, info, "Auto detecting input and norm ...");
 
-   if (info->software_encoding && (info->video_norm==3 || info->video_src==3))
+   if (info->software_encoding && (info->video_norm==3 || info->video_src==-1))
    {
       lavrec_msg(LAVREC_MSG_DEBUG, info,
          "Using current input signal settings for non-MJPEG card");
       return 1;
    }
 
-   if (info->video_src == 3) /* detect video_src && norm */
+   if (info->video_src == -1) /* detect video_src && norm */
    {
       int n = 0;
 
@@ -521,10 +506,7 @@ static uint64_t lavrec_get_free_space(video_capture_setup *settings)
 
    /* check the disk space again */
    if (statfs(settings->stats->output_filename, &statfs_buf))
-   {
-      /* some error happened */
-      MBytes_fs_free = MAX_MBYTES_PER_FILE; /* some fake value */
-   }
+      MBytes_fs_free = 2047; /* some fake value */
    else
    {
       blocks_per_MB = (1024*1024) / statfs_buf.f_bsize;
@@ -946,7 +928,7 @@ static void *lavrec_encoding_thread(void* arg)
 
          jpegsize = encode_jpeg_raw((unsigned char*)(settings->MJPG_buff+current_frame*settings->breq.size),
             settings->breq.size, info->quality, settings->interlaced,
-            CHROMA422, info->geometry->w, info->geometry->h,
+            Y4M_CHROMA_422, info->geometry->w, info->geometry->h,
             settings->YUV_buff+settings->softreq.offsets[current_frame],
             settings->YUV_buff+settings->softreq.offsets[current_frame]+(info->geometry->w*info->geometry->h),
             settings->YUV_buff+settings->softreq.offsets[current_frame]+(info->geometry->w*info->geometry->h*3/2));
@@ -1099,14 +1081,14 @@ static int lavrec_software_init(lavrec_t *info)
    settings->mm.format = VIDEO_PALETTE_YUV422P;
 
    if (info->geometry->h > (info->video_norm==1?320:384))
-      settings->interlaced = LAV_INTER_TOP_FIRST; /* all interlaced BT8x8 capture seems top-first ?? */
+      settings->interlaced = Y4M_ILACE_TOP_FIRST; /* all interlaced BT8x8 capture seems top-first ?? */
    else
-      settings->interlaced = LAV_NOT_INTERLACED;
+      settings->interlaced = Y4M_ILACE_NONE;
 
    lavrec_msg(LAVREC_MSG_INFO, info,
       "Image size will be %dx%d, %d field(s) per buffer",
       info->geometry->w, info->geometry->h,
-      (settings->interlaced==LAV_NOT_INTERLACED)?1:2);
+      (settings->interlaced == Y4M_ILACE_NONE)?1:2);
 
    /* request buffer info */
    if (ioctl(settings->video_fd, VIDIOCGMBUF, &(settings->softreq)) < 0)
@@ -1222,7 +1204,7 @@ static int lavrec_hardware_init(lavrec_t *info)
    /* Set decimation and image geometry params - only if we have weird options */
    if (info->geometry->x != VALUE_NOT_FILLED ||
       info->geometry->y != VALUE_NOT_FILLED ||
-      (info->geometry->h != 0 && info->geometry->h != info->video_norm==1 ? 480 : 576) ||
+      (info->geometry->h != 0 && info->geometry->h != (info->video_norm==1 ? 480 : 576)) ||
       (info->geometry->w != 0 && info->geometry->w != vc.maxwidth) ||
       info->horizontal_decimation != info->vertical_decimation)
    {
@@ -1305,7 +1287,7 @@ static int lavrec_hardware_init(lavrec_t *info)
 
       /* There seems to be some confusion about what is the even and odd field ... */
       /* madmac: 20010810: According to Ronald, this is wrong - changed now to EVEN */
-      bparm.odd_even = lav_query_polarity(info->video_format) == LAV_INTER_TOP_FIRST;
+      bparm.odd_even = lav_query_polarity(info->video_format) == Y4M_ILACE_TOP_FIRST;
       for(n=0; n<bparm.APP_len && n<60; n++) bparm.APP_data[n] = 0;
    }
 
@@ -1366,17 +1348,15 @@ static int lavrec_init(lavrec_t *info)
    /* are there files to capture to? */
    if (info->files) /* yes */
    {
-      /* Handle the limitations of AVI that can only do MAX 2G Byte files */
+/*
+ * If NO filesize limit was specifically given then allow unlimited size.
+ * ODML extensions will handle the AVI files and Quicktime has had 64bit
+ * filesizes for a long time
+*/
       if (info->max_file_size_mb < 0)
-      {
-         if( info->video_format == 'a' || info->video_format == 'A' )
-            info->max_file_size_mb = MAX_MBYTES_PER_FILE_32;
-         else
-            info->max_file_size_mb = MAX_MBYTES_PER_FILE;
-      }
+         info->max_file_size_mb = MAX_MBYTES_PER_FILE_64;
       lavrec_msg(LAVREC_MSG_DEBUG, info,
-         "Maximum size per file will be %d MB",
-         info->max_file_size_mb);
+         "Maximum size per file will be %d MB", info->max_file_size_mb);
 
       if (info->video_captured || info->audio_captured)
       {
@@ -1455,12 +1435,12 @@ static int lavrec_init(lavrec_t *info)
    if (lavrec_autodetect_signal(info) == 0)
       return 0;
 
-   if (info->software_encoding && info->video_src == 3)
+   if (info->software_encoding && info->video_src == -1)
       vch.channel = 0;
    else
       vch.channel = info->video_src;
    vch.norm = info->video_norm;
-   if (info->video_norm != 3 && info->video_src != 3)
+   if (info->video_norm != 3 && info->video_src != -1)
    {
       if (ioctl(settings->video_fd, VIDIOCSCHAN, &vch) < 0)
       {
@@ -2298,7 +2278,7 @@ lavrec_t *lavrec_malloc(void)
    /* let's set some default values now */
    info->video_format = '\0';
    info->video_norm = 3;
-   info->video_src = 3;
+   info->video_src = -1;
    info->software_encoding = 0;
    info->num_encoders = 0; /* this should be set to the number of processors */
    info->horizontal_decimation = 4;
